==> q-4.6.tar.gz: q-4.6/src/mangle.h <==
/* mangle.h: created Mon Jan 5 08:08:56 CET 2004 by mangle.sh */

#define Vflag __qq__Vflag
#define _qinter_consexpr __qq___qinter_consexpr
#define _qinter_error __qq___qinter_error
#define _qinter_eval __qq___qinter_eval
#define _qinter_fileexpr __qq___qinter_fileexpr
#define _qinter_floatexpr __qq___qinter_floatexpr
#define _qinter_free __qq___qinter_free
#define _qinter_funexpr __qq___qinter_funexpr
#define _qinter_intexpr __qq___qinter_intexpr
#define _qinter_mpz_floatexpr __qq___qinter_mpz_floatexpr
#define _qinter_mpzexpr __qq___qinter_mpzexpr
#define _qinter_pipeexpr __qq___qinter_pipeexpr
#define _qinter_strexpr __qq___qinter_strexpr
#define _qinter_usrexpr __qq___qinter_usrexpr
#define _qinter_vectexpr __qq___qinter_vectexpr
#define absname __qq__absname
#define absolute __qq__absolute
#define acquire_input __qq__acquire_input
#define acquire_lock __qq__acquire_lock
#define acquire_tty __qq__acquire_tty
#define actchar __qq__actchar
#define actlineno __qq__actlineno
#define arealloc __qq__arealloc
#define atfork_child __qq__atfork_child
#define atfork_parent __qq__atfork_parent
#define atfork_prepare __qq__atfork_prepare
#define atmpspsz __qq__atmpspsz
#define atmptbsz __qq__atmptbsz
#define aximpsz __qq__aximpsz
#define basename __qq__basename
#define break_handler __qq__break_handler
#define brkdbg __qq__brkdbg
#define brkflag __qq__brkflag
#define change_qpath __qq__change_qpath
#define charstr __qq__charstr
#define chkfile __qq__chkfile
#define clear __qq__clear
#define code __qq__code
#define codesp __qq__codesp
#define codespsz __qq__codespsz
#define consexpr __qq__consexpr
#define debug __qq__debug
#define debug_get_opts __qq__debug_get_opts
#define debug_lock __qq__debug_lock
#define debug_long __qq__debug_long
#define debug_parse_opts __qq__debug_parse_opts
#define dirname __qq__dirname
#define dirstr __qq__dirstr
#define dll_atfork __qq__dll_atfork
#define dll_fini __qq__dll_fini
#define dll_handle __qq__dll_handle
#define dll_init __qq__dll_init
#define dll_name __qq__dll_name
#define echo __qq__echo
#define eflag __qq__eflag
#define end_init __qq__end_init
#define error __qq__error
#define eval __qq__eval
#define evaldef __qq__evaldef
#define evaldef1 __qq__evaldef1
#define exit_thread __qq__exit_thread
#define exitproc __qq__exitproc
#define exitrc __qq__exitrc
#define expand __qq__expand
#define fatal __qq__fatal
#define fexprs __qq__fexprs
#define fformat __qq__fformat
#define fileexpr __qq__fileexpr
#define fini_thread __qq__fini_thread
#define finilex __qq__finilex
#define floatexpr __qq__floatexpr
#define fmode __qq__fmode
#define fnametb __qq__fnametb
#define fparsex __qq__fparsex
#define fprec __qq__fprec
#define fprintx __qq__fprintx
#define funexpr __qq__funexpr
#define funtb __qq__funtb
#define gc_flag __qq__gc_flag
#define gc_tol __qq__gc_tol
#define gc_v __qq__gc_v
#define gcmd __qq__gcmd
#define gcmd_b __qq__gcmd_b
#define gcmd_i __qq__gcmd_i
#define gcmd_s __qq__gcmd_s
#define get_mark __qq__get_mark
#define get_thr __qq__get_thr
#define getint __qq__getint
#define getintexpr __qq__getintexpr
#define getline __qq__getline
#define getln __qq__getln
#define getmodno __qq__getmodno
#define getmpz_floatexpr __qq__getmpz_floatexpr
#define getmpzexpr __qq__getmpzexpr
#define getsym __qq__getsym
#define gettype __qq__gettype
#define gflag __qq__gflag
#define global_mutex __qq__global_mutex
#define globs __qq__globs
#define hashtb __qq__hashtb
#define hashtbsz __qq__hashtbsz
#define have_mark __qq__have_mark
#define hflag __qq__hflag
#define histfile __qq__histfile
#define histmax __qq__histmax
#define iflag __qq__iflag
#define imode __qq__imode
#define impib __qq__impib
#define imports __qq__imports
#define imptb __qq__imptb
#define imptbsz __qq__imptbsz
#define init __qq__init
#define init_mode __qq__init_mode
#define init_qpath __qq__init_qpath
#define init_thread __qq__init_thread
#define initlex __qq__initlex
#define initrc __qq__initrc
#define inittb __qq__inittb
#define inittbsz __qq__inittbsz
#define intexpr __qq__intexpr
#define iscode __qq__iscode
#define issym __qq__issym
#define istype __qq__istype
#define isusrtype __qq__isusrtype
#define kill_threads __qq__kill_threads
#define lastblksz __qq__lastblksz
#define limbsp __qq__limbsp
#define limbspsz __qq__limbspsz
#define longjmp_target __qq__longjmp_target
#define longjump_set __qq__longjump_set
#define mainno __qq__mainno
#define match __qq__match
#define matchp __qq__matchp
#define matchtb __qq__matchtb
#define matchtbsz __qq__matchtbsz
#define maxargs __qq__maxargs
#define maxchars __qq__maxchars
#define maxlevel __qq__maxlevel
#define maxlist __qq__maxlist
#define maxnblks __qq__maxnblks
#define memmax __qq__memmax
#define mksym __qq__mksym
#define modtb __qq__modtb
#define modtbsz __qq__modtbsz
#define mpzexpr __qq__mpzexpr
#define my_mpz_realloc __qq__my_mpz_realloc
#define nargs __qq__nargs
#define new_xprompt __qq__new_xprompt
#define norl __qq__norl
#define nthreads __qq__nthreads
#define nused __qq__nused
#define old_handler __qq__old_handler
#define outid __qq__outid
#define parse_mutex __qq__parse_mutex
#define parsesrc __qq__parsesrc
#define parsex __qq__parsex
#define pchar __qq__pchar
#define peek __qq__peek
#define pfloat __qq__pfloat
#define pipeexpr __qq__pipeexpr
#define pmode __qq__pmode
#define pmpz __qq__pmpz
#define pname __qq__pname
#define pop_mark __qq__pop_mark
#define pop_sigint __qq__pop_sigint
#define prelude __qq__prelude
#define print_trace __qq__print_trace
#define printx __qq__printx
#define prompt __qq__prompt
#define prompt2 __qq__prompt2
#define prompt3 __qq__prompt3
#define pstr __qq__pstr
#define push __qq__push
#define push_mark __qq__push_mark
#define push_sigint __qq__push_sigint
#define pushfile __qq__pushfile
#define pushfloat __qq__pushfloat
#define pushfun __qq__pushfun
#define pushint __qq__pushint
#define pushmpz __qq__pushmpz
#define pushpipe __qq__pushpipe
#define pushstr __qq__pushstr
#define pushuint __qq__pushuint
#define pushvect __qq__pushvect
#define qflag __qq__qflag
#define qmfree __qq__qmfree
#define qmmsg __qq__qmmsg
#define qmnew __qq__qmnew
#define qpath __qq__qpath
#define quitflag __qq__quitflag
#define randomMT __qq__randomMT
#define reads_mutex __qq__reads_mutex
#define readtables __qq__readtables
#define reinit __qq__reinit
#define release_input __qq__release_input
#define release_lock __qq__release_lock
#define release_tty __qq__release_tty
#define reloadMT __qq__reloadMT
#define rerun __qq__rerun
#define restore_sigmask __qq__restore_sigmask
#define resume_input __qq__resume_input
#define roffstb __qq__roffstb
#define roffstbsz __qq__roffstbsz
#define save_sigmask __qq__save_sigmask
#define scanstr __qq__scanstr
#define searchlib __qq__searchlib
#define seedMT __qq__seedMT
#define segv_handler __qq__segv_handler
#define setpath __qq__setpath
#define setvar __qq__setvar
#define sig_handler __qq__sig_handler
#define skip __qq__skip
#define source __qq__source
#define sparsex __qq__sparsex
#define sprintx __qq__sprintx
#define stackmax __qq__stackmax
#define start_init __qq__start_init
#define statetb __qq__statetb
#define statetbsz __qq__statetbsz
#define strexpr __qq__strexpr
#define strsp __qq__strsp
#define strspsz __qq__strspsz
#define substr __qq__substr
#define suspend_input __qq__suspend_input
#define sym_completion __qq__sym_completion
#define symtb __qq__symtb
#define symtbsz __qq__symtbsz
#define sysinfo __qq__sysinfo
#define syssignal __qq__syssignal
#define syssleep __qq__syssleep
#define systime __qq__systime
#define term_handler __qq__term_handler
#define this_thread __qq__this_thread
#define thr0 __qq__thr0
#define thread_atfork __qq__thread_atfork
#define threads __qq__threads
#define tmpspsz __qq__tmpspsz
#define tmptbsz __qq__tmptbsz
#define transtb __qq__transtb
#define transtbsz __qq__transtbsz
#define tty_handler __qq__tty_handler
#define tty_mutex __qq__tty_mutex
#define uintexpr __qq__uintexpr
#define use_readline __qq__use_readline
#define usrexpr __qq__usrexpr
#define vectexpr __qq__vectexpr
#define version __qq__version
#define volstr __qq__volstr
#define wait_threads __qq__wait_threads
#define which __qq__which
#define xblk __qq__xblk
#define xfreep __qq__xfreep
#define xheap __qq__xheap
#define ximp __qq__ximp
#define ximpsz __qq__ximpsz
#define xnblks __qq__xnblks
#define year __qq__year

==> q-7.11.tar.gz: q-7.11/src/mangle.h <==
/* mangle.h: created Mon Dec 17 23:08:07 CET 2007 by mangle.sh */

#define absname __qq__absname
#define absolute __qq__absolute
#define acquire_input __qq__acquire_input
#define acquire_lock __qq__acquire_lock
#define acquire_tty __qq__acquire_tty
#define actbuf __qq__actbuf
#define actchar __qq__actchar
#define actlineno __qq__actlineno
#define arealloc __qq__arealloc
#define atfork_child __qq__atfork_child
#define atfork_parent __qq__atfork_parent
#define atfork_prepare __qq__atfork_prepare
#define atmpspsz __qq__atmpspsz
#define atmptbsz __qq__atmptbsz
#define aximpsz __qq__aximpsz
#define basename __qq__basename
#define break_handler __qq__break_handler
#define brkdbg __qq__brkdbg
#define brkflag __qq__brkflag
#define change_qpath __qq__change_qpath
#define charstr __qq__charstr
#define chkfile __qq__chkfile
#define clear __qq__clear
#define code __qq__code
#define codesp __qq__codesp
#define codespsz __qq__codespsz
#define consexpr __qq__consexpr
#define cstackmax __qq__cstackmax
#define debug __qq__debug
#define debug_get_opts __qq__debug_get_opts
#define debug_lock __qq__debug_lock
#define debug_long __qq__debug_long
#define debug_parse_opts __qq__debug_parse_opts
#define default_codeset __qq__default_codeset
#define default_encoding __qq__default_encoding
#define dirname __qq__dirname
#define dirprefix __qq__dirprefix
#define dirstr __qq__dirstr
#define dll_atfork __qq__dll_atfork
#define dll_fini __qq__dll_fini
#define dll_handle __qq__dll_handle
#define dll_init __qq__dll_init
#define dll_name __qq__dll_name
#define echo __qq__echo
#define eflag __qq__eflag
#define end_init __qq__end_init
#define error __qq__error
#define eval __qq__eval
#define evaldef __qq__evaldef
#define evaldef1 __qq__evaldef1
#define exitproc __qq__exitproc
#define exitrc __qq__exitrc
#define exit_thread __qq__exit_thread
#define expand __qq__expand
#define fatal __qq__fatal
#define fexprs __qq__fexprs
#define fformat __qq__fformat
#define fileexpr __qq__fileexpr
#define finilex __qq__finilex
#define fini_thread __qq__fini_thread
#define floatexpr __qq__floatexpr
#define flush_shift __qq__flush_shift
#define fmode __qq__fmode
#define fnametb __qq__fnametb
#define fparsex __qq__fparsex
#define fprec __qq__fprec
#define fprintx __qq__fprintx
#define funexpr __qq__funexpr
#define funtb __qq__funtb
#define gc_flag __qq__gc_flag
#define gcmd __qq__gcmd
#define gcmd_b __qq__gcmd_b
#define gcmd_i __qq__gcmd_i
#define gcmd_s __qq__gcmd_s
#define gc_tol __qq__gc_tol
#define gc_v __qq__gc_v
#define getint __qq__getint
#define getintexpr __qq__getintexpr
#define getln __qq__getln
#define get_mark __qq__get_mark
#define getmodno __qq__getmodno
#define getmpzexpr __qq__getmpzexpr
#define getmpz_floatexpr __qq__getmpz_floatexpr
#define getsym __qq__getsym
#define get_thr __qq__get_thr
#define gettype __qq__gettype
#define getuintexpr __qq__getuintexpr
#define gflag __qq__gflag
#define global_mutex __qq__global_mutex
#define globs __qq__globs
#define hashtb __qq__hashtb
#define hashtbsz __qq__hashtbsz
#define have_lock __qq__have_lock
#define have_mark __qq__have_mark
#define hflag __qq__hflag
#define histfile __qq__histfile
#define histmax __qq__histmax
#define iflag __qq__iflag
#define imode __qq__imode
#define impib __qq__impib
#define imports __qq__imports
#define imptb __qq__imptb
#define imptbsz __qq__imptbsz
#define init __qq__init
#define initlex __qq__initlex
#define init_mode __qq__init_mode
#define init_qpath __qq__init_qpath
#define initrc __qq__initrc
#define inittb __qq__inittb
#define inittbsz __qq__inittbsz
#define init_thread __qq__init_thread
#define intexpr __qq__intexpr
#define iscode __qq__iscode
#define issym __qq__issym
#define istype __qq__istype
#define isusrtype __qq__isusrtype
#define kill_threads __qq__kill_threads
#define lastblksz __qq__lastblksz
#define limbsp __qq__limbsp
#define limbspsz __qq__limbspsz
#define list_completions __qq__list_completions
#define longjmp_target __qq__longjmp_target
#define longjump_set __qq__longjump_set
#define mainno __qq__mainno
#define match __qq__match
#define matchp __qq__matchp
#define matchtb __qq__matchtb
#define matchtbsz __qq__matchtbsz
#define matchtype __qq__matchtype
#define maxargs __qq__maxargs
#define maxchars __qq__maxchars
#define maxlevel __qq__maxlevel
#define maxlist __qq__maxlist
#define maxnblks __qq__maxnblks
#define memmax __qq__memmax
#define mksym __qq__mksym
#define modtb __qq__modtb
#define modtbsz __qq__modtbsz
#define mpzexpr __qq__mpzexpr
#define my_formatd __qq__my_formatd
#define mygetline __qq__mygetline
#define my_mpz_realloc __qq__my_mpz_realloc
#define my_strtod __qq__my_strtod
#define my_yytext __qq__my_yytext
#define nargs __qq__nargs
#define nbreak __qq__nbreak
#define newsym __qq__newsym
#define new_xprompt __qq__new_xprompt
#define norl __qq__norl
#define nprof __qq__nprof
#define nthreads __qq__nthreads
#define nused __qq__nused
#define old_handler __qq__old_handler
#define outid __qq__outid
#define parse_mutex __qq__parse_mutex
#define parsesrc __qq__parsesrc
#define parsex __qq__parsex
#define peek __qq__peek
#define pfloat __qq__pfloat
#define pipeexpr __qq__pipeexpr
#define pmode __qq__pmode
#define pmpz __qq__pmpz
#define pname __qq__pname
#define pop_mark __qq__pop_mark
#define pop_sigint __qq__pop_sigint
#define prelude __qq__prelude
#define print_breakpoints __qq__print_breakpoints
#define print_profile __qq__print_profile
#define print_trace __qq__print_trace
#define printx __qq__printx
#define process_sentinels __qq__process_sentinels
#define prompt __qq__prompt
#define prompt2 __qq__prompt2
#define prompt3 __qq__prompt3
#define pstr __qq__pstr
#define push __qq__push
#define pushfile __qq__pushfile
#define pushfloat __qq__pushfloat
#define pushfun __qq__pushfun
#define pushint __qq__pushint
#define push_mark __qq__push_mark
#define pushmpz __qq__pushmpz
#define pushpipe __qq__pushpipe
#define push_sigint __qq__push_sigint
#define pushstr __qq__pushstr
#define pushuint __qq__pushuint
#define pushvect __qq__pushvect
#define qflag __qq__qflag
#define _qinter_consexpr __qq___qinter_consexpr
#define _qinter_error __qq___qinter_error
#define _qinter_eval __qq___qinter_eval
#define _qinter_fileexpr __qq___qinter_fileexpr
#define _qinter_floatexpr __qq___qinter_floatexpr
#define _qinter_free __qq___qinter_free
#define _qinter_funexpr __qq___qinter_funexpr
#define _qinter_getsym __qq___qinter_getsym
#define _qinter_gettype __qq___qinter_gettype
#define _qinter_intexpr __qq___qinter_intexpr
#define _qinter_mpzexpr __qq___qinter_mpzexpr
#define _qinter_mpz_floatexpr __qq___qinter_mpz_floatexpr
#define _qinter_pipeexpr __qq___qinter_pipeexpr
#define _qinter_sentinel __qq___qinter_sentinel
#define _qinter_strexpr __qq___qinter_strexpr
#define _qinter_uintexpr __qq___qinter_uintexpr
#define _qinter_usrexpr __qq___qinter_usrexpr
#define _qinter_vectexpr __qq___qinter_vectexpr
#define qmfree __qq__qmfree
#define qmlambda_dtor __qq__qmlambda_dtor
#define qmmsg __qq__qmmsg
#define qmnew __qq__qmnew
#define qmsentinel __qq__qmsentinel
#define qpath __qq__qpath
#define quitflag __qq__quitflag
#define randomMT __qq__randomMT
#define reads_mutex __qq__reads_mutex
#define readtables __qq__readtables
#define reinit __qq__reinit
#define release_input __qq__release_input
#define release_lock __qq__release_lock
#define release_tty __qq__release_tty
#define reloadMT __qq__reloadMT
#define rerun __qq__rerun
#define restore_sigmask __qq__restore_sigmask
#define resume_input __qq__resume_input
#define roffstb __qq__roffstb
#define roffstbsz __qq__roffstbsz
#define save_sigmask __qq__save_sigmask
#define scanstr __qq__scanstr
#define searchlib __qq__searchlib
#define seedMT __qq__seedMT
#define segv_handler __qq__segv_handler
#define setpath __qq__setpath
#define setvar __qq__setvar
#define sig_handler __qq__sig_handler
#define skip __qq__skip
#define source __qq__source
#define sparsex __qq__sparsex
#define sprintx __qq__sprintx
#define stack_dir __qq__stack_dir
#define stackmax __qq__stackmax
#define start_init __qq__start_init
#define statetb __qq__statetb
#define statetbsz __qq__statetbsz
#define strexpr __qq__strexpr
#define strsp __qq__strsp
#define strspsz __qq__strspsz
#define substr __qq__substr
#define suspend_input __qq__suspend_input
#define switch_history __qq__switch_history
#define sym_completion __qq__sym_completion
#define symtb __qq__symtb
#define symtbsz __qq__symtbsz
#define sysinfo __qq__sysinfo
#define syssignal __qq__syssignal
#define syssleep __qq__syssleep
#define systime __qq__systime
#define sys_to_utf8 __qq__sys_to_utf8
#define sys_to_utf8_dup __qq__sys_to_utf8_dup
#define term_handler __qq__term_handler
#define this_thread __qq__this_thread
#define thr0 __qq__thr0
#define thread_atfork __qq__thread_atfork
#define threads __qq__threads
#define tmpspsz __qq__tmpspsz
#define tmptbsz __qq__tmptbsz
#define transtb __qq__transtb
#define transtbsz __qq__transtbsz
#define tty_handler __qq__tty_handler
#define tty_mutex __qq__tty_mutex
#define uintexpr __qq__uintexpr
#define u_isalnum __qq__u_isalnum
#define u_isalpha __qq__u_isalpha
#define u_isdigit __qq__u_isdigit
#define u_islower __qq__u_islower
#define u_ispunct __qq__u_ispunct
#define u_isupper __qq__u_isupper
#define unparseflag __qq__unparseflag
#define use_readline __qq__use_readline
#define usrexpr __qq__usrexpr
#define utf8_to_sys __qq__utf8_to_sys
#define utf8_to_sys_dup __qq__utf8_to_sys_dup
#define vectexpr __qq__vectexpr
#define version __qq__version
#define Vflag __qq__Vflag
#define volstr __qq__volstr
#define wait_threads __qq__wait_threads
#define which __qq__which
#define xblk __qq__xblk
#define xfreep __qq__xfreep
#define xheap __qq__xheap
#define ximp __qq__ximp
#define ximpsz __qq__ximpsz
#define xnblks __qq__xnblks
#define year __qq__year
